use std::{
    fs::File,
    io::{BufRead, BufReader},
};
use std::collections::HashMap;
use std::time::Instant;


const DEFAULT_HASHMAP_LENGTH: usize = 10000;

fn main() {
    let now = Instant::now();
    let mut stations: HashMap<String, onebrc::StationMeasurements> =
        HashMap::with_capacity(DEFAULT_HASHMAP_LENGTH);

    let file = File::open("../../../measurements.txt").expect("File measurements.txt not found");
    let reader = BufReader::new(file);
    for line_result in reader.lines() {
        let line = line_result.expect("could not read line");
        let (station, temp) = line.split_once(';').unwrap();
        let temp = onebrc::parse_temp(temp.as_bytes());
        let measurements_option = stations.get_mut(station);
        if let Some(measurements) = measurements_option {
            measurements.update(temp);
        } else {
            let measurements = onebrc::StationMeasurements {
                min: temp,
                max: temp,
                count: 1,
                sum: temp,
            };
            stations.insert(station.to_owned(), measurements);
        }
    }
    let mut stations: Vec<String> = stations.iter().map(|(&ref station, &ref measurements)| {
        let measurements = measurements.to_string();
        format!("{station}={measurements}")
    }).collect();
    stations.sort();
    let stations = stations.join(",");
    println!("{{{stations}}}");
    println!("Time={} μs", now.elapsed().as_micros());
}

